@@ -188,6 +188,9 @@ func init() {
 		log.Fatal(err)
 	}
 
+	// remove autogenerated apps command
+	resource.RemoveAppsCmd(rootCmd)
+
 	// config is not initialized by cobra at this point, so we need to temporarily initialize it
 	Config.InitConfig()
 
